@@ -47,9 +47,9 @@ class ConnectionStateResponse(KNXIPBodyResponse):
         self.status_code = ErrorCode(raw[1])
         return ConnectionStateResponse.LENGTH
 
-    def to_knx(self) -> list[int]:
+    def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
-        return [self.communication_channel_id, self.status_code.value]
+        return bytes((self.communication_channel_id, self.status_code.value))
 
     def __str__(self) -> str:
         """Return object as readable string."""
