@@ -10,16 +10,7 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 import logging
-from typing import (
-    TYPE_CHECKING,
-    Awaitable,
-    Callable,
-    Generic,
-    Iterator,
-    List,
-    TypeVar,
-    Union,
-)
+from typing import TYPE_CHECKING, Awaitable, Callable, Generic, Iterator, TypeVar, Union
 
 from xknx.dpt.dpt import DPTArray, DPTBinary
 from xknx.exceptions import ConversionError, CouldNotParseTelegram
@@ -38,14 +29,12 @@ if TYPE_CHECKING:
 logger = logging.getLogger("xknx.log")
 
 AsyncCallbackType = Callable[[], Awaitable[None]]
-DPTPayloadType = TypeVar(
-    "DPTPayloadType", DPTArray, DPTBinary, Union[DPTArray, DPTBinary]
-)
-GroupAddressesType = Union["DeviceAddressableType", List["DeviceAddressableType"]]
-ValueType = TypeVar("ValueType")
+DPTPayloadT = TypeVar("DPTPayloadT", DPTArray, DPTBinary, Union[DPTArray, DPTBinary])
+GroupAddressesType = Union["DeviceAddressableType", list["DeviceAddressableType"]]
+ValueT = TypeVar("ValueT")
 
 
-class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
+class RemoteValue(ABC, Generic[DPTPayloadT, ValueT]):
     """Class for managing remote knx value."""
 
     def __init__(
@@ -79,7 +68,7 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
 
         self.device_name: str = "Unknown" if device_name is None else device_name
         self.feature_name: str = "Unknown" if feature_name is None else feature_name
-        self._value: ValueType | None = None
+        self._value: ValueT | None = None
         self.telegram: Telegram | None = None
         self.after_update_cb: AsyncCallbackType | None = after_update_cb
 
@@ -98,19 +87,19 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
             pass
 
     @property
-    def value(self) -> ValueType | None:
+    def value(self) -> ValueT | None:
         """Get current value."""
         return self._value
 
     @value.setter
-    def value(self, value: ValueType | None) -> None:
+    def value(self, value: ValueT | None) -> None:
         """Set new value without creating a Telegram or calling after_update_cb. Raises ConversionError on invalid value."""
         if value is not None:
             # raises ConversionError on invalid value
             self.to_knx(value)
         self._value = value
 
-    async def update_value(self, value: ValueType | None) -> None:
+    async def update_value(self, value: ValueT | None) -> None:
         """Set new value without creating a Telegram. Awaits after_update_cb. Raises ConversionError on invalid value."""
         self.value = value
         if self.after_update_cb is not None:
@@ -147,16 +136,16 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
         return group_address in remote_value_addresses()
 
     @abstractmethod
-    def payload_valid(self, payload: DPTArray | DPTBinary | None) -> DPTPayloadType:
+    def payload_valid(self, payload: DPTArray | DPTBinary | None) -> DPTPayloadT:
         """Return payload if telegram payload may be parsed - to be implemented in derived class."""
         raise CouldNotParseTelegram("Payload invalid", payload=str(payload))
 
     @abstractmethod
-    def from_knx(self, payload: DPTPayloadType) -> ValueType:
+    def from_knx(self, payload: DPTPayloadT) -> ValueT:
         """Convert current payload to value - to be implemented in derived class."""
 
     @abstractmethod
-    def to_knx(self, value: ValueType) -> DPTPayloadType:
+    def to_knx(self, value: ValueT) -> DPTPayloadT:
         """Convert value to payload - to be implemented in derived class."""
 
     async def process(self, telegram: Telegram, always_callback: bool = False) -> bool:
@@ -217,7 +206,7 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
             )
             await self.xknx.telegrams.put(telegram)
 
-    async def set(self, value: ValueType, response: bool = False) -> None:
+    async def set(self, value: ValueT, response: bool = False) -> None:
         """Set new value."""
         if not self.initialized:
             logger.info(
